Authors
=======

[upgrade-requirements.py][home] is written and maintained by Joe Esposito,
along with the following contributors:

- Emile Caron ([@emilecaron](https://github.com/emilecaron))
- ZHOU Cheng ([@ldsink](https://github.com/ldsink))


[home]: README.md
